Semirobust covariance matrix estimators for models of class "prais".
# S3 method for prais
vcovHC(x, type = c("const", "HC1", "HC0"), ...)An object of class "matrix" containing the estimate of the asymptotic covariance matrix of coefficients.
an object of class "prais", usually, the result of a call to prais_winsten.
a character string specifying the estimation type.
not used.
vcovHC is a function for estimating a robust covariance matrix of parameters for
the Prais-Winsten estimator. The weighting schemes specified by type are analogous to those in
vcovHC in package sandwich
with the caveat that only "const", "HC0" and "HC1" are available.
vcovHC